aboutsummaryrefslogtreecommitdiffhomepage
path: root/bench/ChartBench.cpp
diff options
context:
space:
mode:
authorGravatar halcanary <halcanary@google.com>2015-08-27 07:41:13 -0700
committerGravatar Commit bot <commit-bot@chromium.org>2015-08-27 07:41:16 -0700
commit96fcdcc219d2a0d3579719b84b28bede76efba64 (patch)
tree0ec5ea0193d8292df8bf5ed9dd8498a5eb5763dd /bench/ChartBench.cpp
parent435af2f736c85c3274a0c6760a3523810750d237 (diff)
Style Change: NULL->nullptr
Diffstat (limited to 'bench/ChartBench.cpp')
-rw-r--r--bench/ChartBench.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/bench/ChartBench.cpp b/bench/ChartBench.cpp
index 61f97a2f2a..8b3aa73cff 100644
--- a/bench/ChartBench.cpp
+++ b/bench/ChartBench.cpp
@@ -29,7 +29,7 @@ static void gen_data(SkScalar yAvg, SkScalar ySpread, int count,
// Generates a path to stroke along the top of each plot and a fill path for the area below each
// plot. The fill path is bounded below by the bottomData plot points or a horizontal line at
// yBase if bottomData == NULL.
// The plots are animated by rotating the data points by leftShift.
static void gen_paths(const SkTDArray<SkScalar>& topData,
const SkTDArray<SkScalar>* bottomData,
@@ -40,7 +40,7 @@ static void gen_paths(const SkTDArray<SkScalar>& topData,
plot->rewind();
fill->rewind();
plot->incReserve(topData.count());
- if (NULL == bottomData) {
+ if (nullptr == bottomData) {
fill->incReserve(topData.count() + 2);
} else {
fill->incReserve(2 * topData.count());
@@ -149,7 +149,7 @@ protected:
fillPaint.setAntiAlias(fAA);
fillPaint.setStyle(SkPaint::kFill_Style);
- SkTDArray<SkScalar>* prevData = NULL;
+ SkTDArray<SkScalar>* prevData = nullptr;
for (int i = 0; i < kNumGraphs; ++i) {
gen_paths(fData[i],
prevData,
@@ -29,7 +29,7 @@ static void gen_data(SkScalar yAvg, SkScalar ySpread, int count,
// Generates a path to stroke along the top of each plot and a fill path for the area below each
// plot. The fill path is bounded below by the bottomData plot points or a horizontal line at
-// yBase if bottomData == NULL.
+// yBase if bottomData == nullptr.
// The plots are animated by rotating the data points by leftShift.
static void gen_paths(const SkTDArray<SkScalar>& topData,